#
# spec file for package connman
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define	openconnect_present	(0%{?suse_version} > 1500)
# hh2serial and tist is not building correctly on PPC and I don't intend to fix that
%ifarch ppc ppc64 ppc64le
%define hh2serial_working	0
%define tist_working		0
%else
%define hh2serial_working	1
%define tist_working		1
%endif
%ifarch i586
%define vpnc_present		0
%else
%define vpnc_present		1
%endif
Name:           connman
Version:        1.41
Release:        bp153.2.3.1
Summary:        Connection Manager
License:        GPL-2.0-only
Group:          System/Daemons
URL:            http://www.moblin.org/
Source0:        http://www.kernel.org/pub/linux/network/connman/connman-%{version}.tar.xz
Source1:        http://www.kernel.org/pub/linux/network/connman/connman-%{version}.tar.sign
Source2:        connman.keyring
# PATCH-FIX-OPENSUSE -- Greate symlink to network.service
# downstream patches
Patch100:       0100-connman-1.35-service.patch
Patch101:       0101-harden_connman-vpn.service.patch
Patch102:       0102-harden_connman-wait-online.service.patch
BuildRequires:  dhcp
BuildRequires:  openvpn
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
BuildRequires:  wpa_supplicant
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(glib-2.0) >= 2.28
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(libiptc)
BuildRequires:  pkgconfig(libmnl)
BuildRequires:  pkgconfig(polkit-agent-1)
BuildRequires:  pkgconfig(xtables)
Requires:       bluez
Requires:       dhcp >= 3.0.2
Requires:       iptables
Requires:       wpa_supplicant
Recommends:     %{name}-client
%{?systemd_requires}

%description
Connection Manager provides a daemon for managing Internet connections
within embedded devices running the Linux operating system.

%package devel
Summary:        Development files for Connection Manager
Group:          Development/Libraries/C and C++
Requires:       %{name} >= %{version}

%description devel
connman-devel contains development files for use with connman.

%package doc
Summary:        Connman reference man pages
Group:          Documentation/Man

%description doc
Documentation in form of man pages for Connman (Connection Manager).

##############################
#Plugins
##############################
%if %{hh2serial_working}
%package plugin-hh2serial-gps
Summary:        HH2Serial GPS plugin for connman
Group:          System/Daemons
Requires:       %{name} >= %{version}

%description plugin-hh2serial-gps
Provides HH2Serial GPS device support for Connman (Connection Manager).
%endif

%if %{openconnect_present}
%package plugin-openconnect
Summary:        OpenConnect plugin for connman
Group:          System/Daemons
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(openconnect)
Requires:       %{name} >= %{version}
Requires:       dbus-1 >= 1.0
Requires:       openconnect

%description plugin-openconnect
Provides OpenConnect support for Connman (Connection Manager).
OpenConnect is an open client for Cisco(TM) AnyConnect(TM) VPN.
%endif

%if %{vpnc_present}
%package plugin-vpnc
Summary:        VPNC plugin for connman
Group:          System/Daemons
BuildRequires:  vpnc
Requires:       %{name} >= %{version}
Requires:       vpnc

%description plugin-vpnc
Provides VPNC support for Connman (Connection Manager).
%endif

%package plugin-openvpn
Summary:        OpenVPN plugin for connman
Group:          System/Daemons
BuildRequires:  openvpn
Requires:       %{name} >= %{version}
Requires:       openvpn

%description plugin-openvpn
Provides OpenVPN support for Connman (Connection Manager).

%package plugin-pptp
Summary:        PPTP plugin for connman
Group:          System/Daemons
Requires:       %{name} >= %{version}

%description plugin-pptp
Provides PPTP support for Connman (Connection Manager).

%package plugin-wireguard
Summary:        WireGuard plugin for connman
Group:          System/Daemons
Requires:       %{name} >= %{version}

%description plugin-wireguard
Provides WireGuard network support for Connman (Connection Manager).


%if %{tist_working}
%package plugin-tist
Summary:        TIST plugin for connman
Group:          System/Daemons
Requires:       %{name} >= %{version}

%description plugin-tist
Provides TI Shared Transport support for Connman (Connection Manager).
%endif

%package plugin-l2tp
Summary:        L2TP plugin for connman
Group:          System/Daemons
Requires:       %{name} >= %{version}

%description plugin-l2tp
Provides L2TP (Layer 2 Tunneling Protocol) support for Connman (Connection Manager).

%package plugin-iospm
Summary:        Intel OSPM plugin for connman
Group:          System/Daemons
BuildRequires:  ppp-devel
Requires:       %{name} >= %{version}
Requires:       ppp

%description plugin-iospm
Provides Intel OSPM support for Connman (Connection Manager).

%package test
Summary:        Test and example scripts for connman
Group:          System/Daemons
Requires:       %{name} >= %{version}

%description test
Provides test and example scripts for Connman (Connection Manager).

%package nmcompat
Summary:        NetworkManager compatibility for connman
Group:          System/Daemons
Requires:       %{name} >= %{version}
# This package install D-Bus rules that are different than the ones from
# NetworkManager, only allow the installation of one of them
Conflicts:      NetworkManager

%description nmcompat
Provides NetworkManager compatibility for Connman (Connection Manager).

%package plugin-polkit
Summary:        PolicyKit plugin for connman
Group:          System/Daemons
Requires:       %{name} >= %{version}
Requires:       dbus-1 >= 1.0
Requires:       polkit

%description plugin-polkit
Provides PolicyKit support for Connman (Connection Manager).

%package client
Summary:        Client script for connman
Group:          System/Daemons
Requires:       %{name} >= %{version}

%description client
Provides client interface for Connman (Connection Manager).

%prep
%autosetup -p1 -n connman-%{version}

%build
# Using i586 repository, so explicitly forward it to CC.
# Necesary, because i386 will fail due to:
# undefined reference to `__sync_add_and_fetch_4'
# Restrict to Fedora right for now.
%if 0%{?fedora}
%ifarch i386 i486 i586
CFLAGS='-O2 -g -march=i586 -mtune=i686'
export CFLAGS
CXXFLAGS='-O2 -g -march=i586 -mtune=i686'
export CXXFLAGS
FFLAGS='-O2 -g -march=i586 -mtune=i686'
export FFLAGS
%endif
%endif

%configure --enable-shared \
           --with-systemdunitdir=%{_unitdir} \
           --disable-debug \
           --enable-pie \
%if %{hh2serial_working}
           --enable-hh2serial-gps \
%endif
%if %{openconnect_present}
           --enable-openconnect \
%endif
           --enable-openvpn \
%if %{vpnc_present}
           --enable-vpnc \
%endif
           --enable-l2tp \
           --enable-pptp \
           --enable-iospm \
%if %{tist_working}
           --enable-tist \
%endif
           --enable-test \
           --enable-nmcompat \
           --enable-polkit \
           --enable-loopback \
           --enable-ethernet \
           --enable-wifi \
           --enable-bluetooth \
           --enable-ofono \
           --enable-dundee \
           --enable-pacrunner \
           --enable-wispr \
           --enable-client \
           --enable-tools \
           --enable-datafiles

%make_build

%install
%make_install

mkdir -p \
	%{buildroot}%{_localstatedir}/lib/%{name} \
	%{buildroot}%{_localstatedir}/lib/%{name}-vpn

touch %{buildroot}%{_localstatedir}/lib/%{name}/settings

install -Dm0755 {client,%{buildroot}/%{_bindir}}/connmanctl
install -Dm0644 {src,%{buildroot}%{_sysconfdir}/%{name}}/main.conf

%if %{openconnect_present} || %{vpnc_present}
rm %{buildroot}%{_libdir}/connman/scripts/vpn-script
%endif

find %{buildroot} -type f -name "*.la" -delete -print

%pre
%service_add_pre connman.service
%service_add_pre connman-vpn.service
%service_del_postun connman-wait-online.service

%post
%service_add_post connman.service
%service_add_post connman-vpn.service
%service_del_postun connman-wait-online.service
%tmpfiles_create %{_tmpfilesdir}/connman.conf
%tmpfiles_create %{_tmpfilesdir}/connman_resolvconf.conf
if ! readlink %{_sysconfdir}/systemd/system/network.service &> /dev/null; then
	%{_bindir}/systemctl --system daemon-reload || :
	%{_bindir}/systemctl --force enable connman.service || :
elif [ $1 -eq 1 ]; then
mkdir -p %{_localstatedir}/adm/update-messages
rm -f %{_localstatedir}/adm/update-messages/%{name}-%{version}-%{release}
cat > %{_localstatedir}/adm/update-messages/%{name}-%{version}-%{release} << EOF
INFO: Please ensure that the network services disabled:
INFO: Yast2 -> Network Settings -> Global Option -> Network Setup Method -> Network Services Disabled
INFO: or using the command line
INFO: systemctl disable $(readlink %{_sysconfdir}/systemd/system/network.service | sed 's/.*\///')
EOF
fi

%preun
%service_del_preun connman.service
%service_del_preun connman-vpn.service
%service_del_preun connman-wait-online.service

%postun
%service_del_postun connman.service
%service_del_postun connman-vpn.service
%service_del_postun connman-wait-online.service

%files
%license COPYING
%doc AUTHORS ChangeLog README
%{_sbindir}/connmand
%{_sbindir}/connman-vpnd
%{_sbindir}/connmand-wait-online
%{_tmpfilesdir}/connman_resolvconf.conf
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/scripts
%dir %{_libdir}/%{name}/plugins
%dir %{_libdir}/%{name}/plugins-vpn
%{_datadir}/dbus-1/system.d/connman.conf
%{_datadir}/dbus-1/system.d/connman-vpn-dbus.conf
%{_datadir}/dbus-1/system-services/net.connman.vpn.service
%{_unitdir}/connman.service
%{_unitdir}/connman-vpn.service
%{_unitdir}/connman-wait-online.service
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/main.conf
%ghost %dir %{_localstatedir}/lib/%{name}
%ghost %dir %{_localstatedir}/lib/%{name}-vpn
%ghost %{_localstatedir}/lib/%{name}/settings

%files devel
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*.h
%{_libdir}/pkgconfig/*.pc

%files doc
%{_mandir}/*/*

#plugins
%if %{hh2serial_working}
%files plugin-hh2serial-gps
%{_libdir}/%{name}/plugins/hh2serial-gps.so
%endif

%if %{openconnect_present}
%files plugin-openconnect
%{_libdir}/%{name}/plugins-vpn/openconnect.so
%endif

%if %{vpnc_present}
%files plugin-vpnc
%{_libdir}/%{name}/plugins-vpn/vpnc.so
%endif

%files plugin-iospm
%{_libdir}/%{name}/plugins/iospm.so

%files plugin-l2tp
%{_libdir}/%{name}/plugins-vpn/l2tp.so
%{_libdir}/%{name}/scripts/libppp-plugin.so*

%files plugin-openvpn
%{_libdir}/%{name}/plugins-vpn/openvpn.so
%{_libdir}/%{name}/scripts/openvpn-script

%files plugin-pptp
%{_libdir}/%{name}/plugins-vpn/pptp.so

%files plugin-wireguard
%{_libdir}/connman/plugins-vpn/wireguard.so

%if %{tist_working}
%files plugin-tist
%{_libdir}/%{name}/plugins/tist.so
%endif

%files test
%{_libdir}/%{name}/test

%files nmcompat
%{_datadir}/dbus-1/system.d/connman-nmcompat.conf

%files plugin-polkit
%{_datadir}/polkit-1/actions/net.connman.policy
%{_datadir}/polkit-1/actions/net.connman.vpn.policy

%files client
%{_bindir}/connmanctl

%changelog
* Fri Feb 11 2022 Daniel Wagner <daniel.wagner@suse.com>
- Update to 1.41: (bsc#1194177, bsc#1194176, bsc#1194175)
  * Fix issue with RTNL netlink message alignment.
  * Fix issue with dnsproxy and timeout for TCP feature. (CVE-2022-23097, CVE-2022-23096)
  * Fix issue with dnsproxy and busy loop in TCP server. (CVE-2022-23098)
  * Fix issue with WiFi connection with no passphrase.
  * Add support for wpa_supplicant and WPA3-SAE functionality.
  * Add support for D-Bus ObjectManager interface.
- Renamed downstream patches to separate them from upstream patches
  * Rename 0001-connman-1.35-service.patch to 0100-connman-1.35-service.patch
- Add systemd hardening configuration
  * Rename harden_connman-vpn.service.patch to 0101-harden_connman-vpn.service.patch
  * Rename harden_connman-wait-online.service.patch to 0102-harden_connman-wait-online.service.patch
- Disabled openconnect plugin due to version conflict
- Disabled vpnc plugin for i568 missing dependency
- Disabled hh2serial and tist_working for ppc64le due to version conflict
* Fri Feb 12 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.39 (bsc#1181751):
  * Fix issue with scanning state synchronization and iwd.
  * Fix issue with invalid key with 4-way handshake offloading.
  * Fix issue with DNS proxy length checks to prevent buffer overflow. (CVE-2021-26675)
  * Fix issue with DHCP leaking stack data via uninitialized variable. (CVE-2021-26676)
* Tue Feb 18 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.38:
  * Fix issue with online check on IP address update.
  * Fix issue with OpenVPN and encrypted private keys.
  * Fix issue with finishing of VPN connections.
  * Add support for updated stable iwd APIs.
  * Add support for WireGuard networks.
- Spec file cleanup
* Fri May 10 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.37:
  * Fix issue with handling invalid gateway addresses.
  * Fix issue with handling updates of default gateway.
  * Fix issue with DHCP servers that require broadcast flag.
  * Add support for option to use gateways as time servers.
  * Add support for option to select default technology.
  * Add support for Address Conflict Detection (ACD).
  * Add support for IPv6 iptables management.
- Change in 1.36:
  * Fix issue with DNS short response on error handling.
  * Fix issue with handling incoming DNS requests.
  * Fix issue with handling empty timeserver list.
  * Fix issue with incorrect DHCP byte order.
  * Fix issue with AllowDomainnameUpdates handling.
  * Fix issue with IPv4 link-local IP conflict error.
  * Fix issue with handling WISPr over TLS connections.
  * Fix issue with WiFi background scanning handling.
  * Fix issue with WiFi disconnect+connect race condition.
  * Fix issue with WiFi scanning and tethering operation.
  * Fix issue with WiFi security change handling.
  * Fix issue with missing signal for WPS changes.
  * Fix issue with online check retry handling.
  * Add support for systemd-resolved backend.
  * Add support for mDNS configuration setup.
- Drop connman-1.35-include.patch
- Drop connman-1.35-resolvconf.patch
* Tue Feb 13 2018 avvissu@yandex.by
- Fix build errors due to unsupported header include order with
  newer kernels >=4.15 (connman-1.35-include.patch).
* Tue Dec 26 2017 avvissu@yandex.by
- Add symlink to network.service (connman-1.35-service.patch)
* Thu Oct 26 2017 avvissu@yandex.by
- Change the mode of download_files (sr#521762)
- Remove connman-rpmlintrc (bnc#1057697)
- Add client as a recommended dependency
* Fri Oct 20 2017 avvissu@yandex.by
- Remove unrecognized options: disable-gtk-doc, enable-threads,
  disable-iwmx, enable-session-policy
* Thu Oct 19 2017 avvissu@yandex.by
- Add configuration file (/etc/connman/main.conf)
- Add ghost lines: main.conf connman connman-vpn
* Tue Oct  3 2017 avvissu@yandex.by
- Add connman-1.35-resolvconf.patch
- Activate connman.service if the network services disabled
- Add info in /var/adm/update-messages
* Fri Sep  8 2017 avvissu@yandex.by
- Remove obsolete macros
- Add polkit-agent-1 dependency
- Use the %%tmpfiles_create macro
- Removal of ldconfig scriptlets from all packages
- Add connman-wait-online.service in post{un}
- Spec file cleanup
* Tue Aug 22 2017 sleep_walker@opensuse.org
- bump to 1.35
  besides other things contains fix for CVE-2017-12865
* Tue Oct 13 2015 sleep_walker@opensuse.org
- bumpt to 1.30
    Fix issue with pending DNS request during server change.
    Fix issue with empty strings in nameservers configuration.
    Fix issue with time servers during IP configuration change.
    Fix issue with 4-way handshake during roaming.
    Fix issue with open WiFi networks security.
    Fix issue with support for WiFi AnonymousIdentity.
    Fix issue with memory leak and DHCPv6 DUID handling.
    Fix issue with DHCP client and P2P interaction.
    Fix issue with handling provision file updates.
    Fix issue with VPN state updates.
    Disable 6to4 support by default.
- add keyring file
- clean with spec-cleaner
- fix builds for all possible distributions and architectures
* Fri Aug  7 2015 sleep_walker@opensuse.org
- bump to 1.29
  Fix issue with IPv6 autoconfiguration when disabled.
  Fix issue with IPv6 temporary route handling.
  Fix issue with IPv6 timers for nameservers.
  Fix issue with DHPCv6 and route configuration.
  Fix issue with DHCPv6 source port and buggy servers.
  Fix issue with DHCPv6 rapid commit option length.
  Fix issue with DHCPv6 rapid commit error handling.
  Fix issue with handling invalid WiFi passphrases.
  Fix issue with connecting Ethernet devices.
  Add support for Ethernet and VLAN usage.
* Fri Feb  6 2015 sleep_walker@suse.cz
- bump to 1.28
  ver 1.28:
  Fix issue with DHCPv6 re-transmission timer.
  Fix issue with DHCP service ID option byte order.
  Fix issue with IPv6 connections and SLAAC/DHCPv6.
  Fix issue with telephony and IPv6 autoconfiguration.
  Fix issue with Bluetooth technology setting changes.
  Fix issue with WiFi autoscan interval calculation.
  Fix issue with WiFi and missing BSS signal strength.
  Add support for IPv4 information for WiFi Display.
  ver 1.27:
  Fix issue with memory leak in IP configuration.
  Fix issue with providing random numbers for DHCP.
  Fix issue with handling IN_MOVED_TO inotify events.
  Fix issue with channel selection for WiFi scanning.
  Add support for handling Bluetooth GN and PANU roles.
  ver 1.26:
  Fix issue with missing WiFi security provisioning support.
  Fix issue with immutable setting and provisioned services.
  Fix issue with scheduling DNS cache cleanup procedure.
  Fix issue with IPv6 Privacy setting on service removal.
  Fix issue with DHCPv6 CONFIRM message sending procedure.
  Fix issue with DHCPv6 lease expiration handling support.
  Fix issue with DHCPv4 networks and broadcast flag handling.
  Fix issue with DHCPv4 networks without gateway configuration.
  Fix issue with P2P Peer authorization handling.
  Fix issue with P2P Peer service registration.
  Add support for WiFi Display information elements.
  Add support for systemd-hostnamed integration.
  ver 1.25:
  Fix issue with handling rebind timer for DHCPv6.
  Fix issue with handling DHCP renew transaction.
  Fix issue with user supplied proxy settings and DHCP.
  Fix issue with extra status codes from captive portals.
  Fix issue with service idle state reset on failure.
  Fix issue with DNS label compression handling.
  Add support for experimental P2P Peer service.
  ver 1.24:
  Fix issue with handling slave interfaces.
  Fix issue with handling DHCPv4 broadcast flag.
  Fix issue with handling DHCPv4 lease expiration.
  Fix issue with handling WiFi auto-scanning timeout.
  Fix issue with handling domain and DNS server changes.
  Fix issue with double free and agent messages.
  ver 1.23:
  Fix issue with memory leak in technology handling.
  Fix issue with not removing host route of OpenVPN.
  Fix issue with double free in DHCP cleanup handling.
  Fix issue with handling DHCP method from oFono.
  Fix issue with IPv6-PD when disabling tethering.
  Fix issue with DNS proxy when disabling tethering.
  Fix issue with Bluetooth start and stop interaction.
  Fix issue with Bluetooth PAN networks on adapter change.
  ver 1.22:
  Fix issue with WPS state synchronization.
  Fix issue with DNS servers and default service.
  Fix issue with DHCP client and rebooting state.
  Add support for NTP exponential backoff handling.
  Add support for NTP kiss-of-death packet handling.
  Add support for Ethernet gadget networking.
* Tue Jul 15 2014 jmatejka@suse.cz
- Install connmanctl in connman-client package
* Wed Feb 19 2014 simon@simotek.net
- bump to 1.21
    Hidden SSID scanning works again and the security mode of the found WiFi network is checked against the one requested (Tomasz Bursztyka).
    Fix failure when enabling Bluetooth using Bluez 5.x (Zhang Zhengguang)
    GTK-doc generated documentation hasn't seen any use in a long time and has become sufficiently broken in order to be removed (Ross Burton). Notice that ConnMan documentation still continues to exist in the ./doc directory.
    Fix a few minor issues discovered by Coverity (Daniel Wagner) and add DNS buffer validation (Jaehyun Kim).
    Properly handle proxies whether they are IP addresses or host names (Sjoerd Simons)
* Tue Dec 17 2013 sleep_walker@suse.cz
- bump to 1.20
  ver 1.20:
    Fix issue with invalid cache of DNS proxy support.
    Fix issue with stopping DHCP for failed connections.
    Fix issue with not stopping IPv4 Link-Local state machine.
    Fix issue with service type handling for unknown interfaces.
    Fix issue with using interface names instead of indexes.
    Fix issue with resetting network retry counter on failure.
    Fix issue with using nameservers when its type is not enabled.
    Fix issue with fallback nameservers not being used.
    Add support for NTP version 3 protocol.
  ver 1.19:
    Fix issue with not correctly storing IPv4 method.
    Fix issue with changing the default service too early.
    Fix issue with service reference count and WISPr checks.
    Fix issue with service auto-connect handling and ordering.
    Fix issue with host and domain names when service changes.
    Fix issue with proxy result and WISPr handling.
    Fix issue with proxy reset when disconnecting.
    Fix issue with handling fallback nameservers.
    Add support for multiple agents.
* Tue Sep 24 2013 guillaume@opensuse.org
- Update to 1.18
* Sat Jun  8 2013 simon@simotek.net
- Properly handle vpn service with systemd
* Sat Jun  1 2013 simon@simotek.net
- Update to 1.15
- 1.12 never built (My Fault)
- Various bug fixes including to tethering, DHCPv6 and commandline
  client amoungst others
* Sat Mar 23 2013 simon@simotek.net
- Update to 1.12
- New Bluetooth and VPN features amongst others
* Sun Nov 25 2012 simon@simotek.net
- Meet Packaging Guidelines for systemd packages in openSUSE
- Remove some tabs from the spec file
* Fri Nov 23 2012 sleep_walker@suse.cz
- fix dependency name
* Fri Nov 23 2012 sleep_walker@suse.cz
- remove *_version conditions as it is handled in meta prjconf
* Fri Nov 23 2012 sleep_walker@suse.cz
- update to 1.9
- reorder configure to follow ./configure --help order
- add wpa_supplicant to Buildrequires
- enable session_policy plugin
* Tue Sep 25 2012 sleep_walker@suse.cz
- update dependencies to work on SUSE distros II.
* Tue Sep 25 2012 sleep_walker@suse.cz
- update dependencies to work on SUSE distros
* Sun Sep 23 2012 sleep_walker@suse.cz
- move files across packages, move requires and buildrequires
* Sat Sep 22 2012 sleep_walker@suse.cz
- fix deps for oS12.2+
* Sat Sep 22 2012 sleep_walker@suse.cz
- update to 1.7, add more subpackages
